@@ -1,18 +1,16 @@
-# $Id: LibXML.pm,v 1.7 2003/09/29 10:37:43 pajas Exp $
+# $Id: LibXML.pm,v 1.1 2002/03/06 10:55:50 pajas Exp $
 
 package XML::Normalize::LibXML;
 
 use strict;
 use Exporter;
 use XML::LibXML;
-use XML::LibXML::Iterator;
-
 use vars qw(@ISA @EXPORT_OK $VERSION);
 
 BEGIN {
   @ISA = qw(Exporter);
-  @EXPORT_OK = qw(trim xml_normalize xml_strip_whitespace xml_strip_element);
-  $VERSION='0.2'
+  @EXPORT_OK = qw(trim xml_normalize xml_strip_whitespace);
+  $VERSION='0.1'
 }
 
 sub trim {
@@ -28,7 +26,7 @@ sub xml_normalize {
 
   foreach my $node ($node->childNodes()) {
     my $type = $node->nodeType;
-    if ($type == XML::LibXML::XML_TEXT_NODE) {
+    if ($type == XML_TEXT_NODE) {
       if ($prev) {
 	$prev->setData($prev->getData().$node->getData());
 	$node->unbindNode();
@@ -37,7 +35,7 @@ sub xml_normalize {
       }
     } else {
       $prev = undef;
-      if ($type == XML::LibXML::XML_ELEMENT_NODE) {
+      if ($type == XML_ELEMENT_NODE) {
 	xml_normalize($node);
       }
     }
@@ -46,19 +44,14 @@ sub xml_normalize {
 
 sub xml_strip_whitespace_text_node {
   my ($node)=@_;
-  if ($node->nodeType() == XML::LibXML::XML_TEXT_NODE) {
-    my $data=trim($node->getData());
-    if ($data ne "") {
-      $node->setData($data);
-    } else {
-      $node->unbindNode();
-    }
+  if ($node->nodeType() == XML_TEXT_NODE) {
+    $node->setData(trim($node->getData()));
   }
 }
 
 sub xml_strip_whitespace_attributes {
   my ($node)=@_;
-  if ($node->nodeType() == XML::LibXML::XML_ELEMENT_NODE) {
+  if ($node->nodeType() == XML_ELEMENT_NODE) {
     foreach my $attr ($node->attributes()) {
       $node->setValue(trim($node->getValue()));
     }
@@ -68,52 +61,16 @@ sub xml_strip_whitespace_attributes {
 sub xml_strip_whitespace {
   my ($dom, $strip_attributes)=@_;
   xml_normalize($dom);
-  my $iter= XML::LibXML::Iterator->new( $dom );
-
   if ($strip_attributes) {
-    $iter->iterate(sub {
-		     xml_strip_whitespace_attributes($_[1]);
-		     xml_strip_whitespace_text_node($_[1]);
+    $dom->iterator(sub {
+		     xml_strip_whitespace_text_node($_[0]);
+		     xml_strip_whitespace_attributes($_[0]);
 		   });
   } else {
-    $iter->iterate(sub {
-		     xml_strip_whitespace_text_node($_[1]);
-		   });
+    $dom->iterator(\&xml_strip_whitespace_text_node);
   }
 }
 
-sub xml_strip_element {
-  my ($node)=@_;
-  return unless $node->nodeType == XML::LibXML::XML_ELEMENT_NODE;
-
-  my $f = $node->firstChild;
-  while ($f and $f->nodeType == XML::LibXML::XML_TEXT_NODE and
-	 $f->getData =~ /^\s/) {
-    my $data=$f->getData();
-    $data=~s/^\s+//;
-    if ($data ne "") { 
-      $f->setData($data);
-      last;
-    } else {
-      $f->unbindNode();
-      $f = $node->firstChild;
-    }
-  }
-
-  my $f = $node->lastChild;
-  while ($f and $f->nodeType == XML::LibXML::XML_TEXT_NODE and
-	 $f->getData =~ /\s$/) {
-    my $data=$f->getData();
-    $data=~s/\s+$//;
-    if ($data ne "") {
-      $f->setData($data);
-      last;
-    } else {
-      $f->unbindNode();
-      $f = $node->lastChild;
-    }
-  }
-}
 
 1;
 
@@ -123,11 +80,11 @@ __END__
 
 =head1 NAME
 
-XML::Normalize::LibXML - simple whitespace striping functions
+XML::LibXML::Normalize - simple whitespace striping functions
 
 =head1 SYNOPSIS
 
-use XML::Normalize::LibXML qw(trim xml_normalize xml_strip_whitespace);
+use XML::LibXML::Normalize qw(trim xml_normalize xml_strip_whitespace);
 
 $greeting=trim("   hallo world    ");  # returns "hallo world"
 xml_normalize($dom->getDocumentElement());
@@ -135,7 +92,7 @@ xml_strip_whitespace($dom->getDocumentElement());
 
 =head1 DESCRIPTION
 
-This module provides simple whitespace striping and text-node
+This module provides simple white-space striping and text-node
 normalizing functions.
 
 =head2 C<trim($string)>
@@ -161,10 +118,6 @@ the subtree. If the optional argument $include_attributes is defined
 and non-zero, this function trims whitespace also from all Attribute
 nodes.
 
-=head2 C<xml_strip_element($node)>
-
-Removes leading and trailing whitespace from a given element.
-
 =head1 AUTHOR
 
 Petr Pajas, pajas@matfyz.cz
